@@ -1,5 +1,5 @@
 // feedback.cc - source file for the mailfilter program
-// Copyright (c) 2000 - 2009  Andreas Bauer <baueran@gmail.com>
+// Copyright (c) 2000 - 2022  Andreas Bauer <baueran@gmail.com>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -59,6 +59,17 @@ bool Feedback :: open (const char* name)
   return false;
 }
 
+
+string Feedback::timestamp()
+{
+  char timestamp[64];
+  time_t timer = time(NULL);
+  struct tm* tm_info = localtime(&timer);
+  strftime (timestamp, sizeof(timestamp), "%b %d %H:%M:%S", tm_info);
+  return string(timestamp);
+}
+
+
 // The following two functions attempt to append program messages to
 // the end of the log file and returns false, if the file is not
 // accessable.  True is returned otherwise.
@@ -71,10 +82,11 @@ bool Feedback :: print_msg (const string msg, int min_verbose_level)
 {
   if (Preferences :: Instance ().verbose_level () >= min_verbose_level)
     {
-      cout << "mailfilter: " << msg << endl;
+      string ts = timestamp();
+      cout << ts << " mailfilter: " << msg << endl;
 	
       if (log_file.is_open ())
-	log_file << "mailfilter: " << msg << endl;
+	log_file << ts << " mailfilter: " << msg << endl;
       else
 	return false;
     }
@@ -86,10 +98,11 @@ bool Feedback :: print_err (const string msg, int min_verbose_level)
 {
   if (Preferences :: Instance ().verbose_level () >= min_verbose_level)
     {
-      cerr << "mailfilter: Error: " << msg << endl;
+      string ts = timestamp();
+      cerr << ts << " mailfilter: Error: " << msg << endl;
 	
       if (log_file.is_open ())
-	log_file << "mailfilter: Error: " << msg << endl;
+	log_file << ts << " mailfilter: Error: " << msg << endl;
       else
 	return false;
     }
